
# ====================================================================

	set HEIGHT 400.0
	set WIDTH  300.0
	set wToX    5
	set hToY   25

	proc screen {w h}  {
		global WIDTH HEIGHT hToY  wToX

		set wToX [expr $w * $WIDTH]
		set hToY [expr $h / $HEIGHT]

		canvas .c -width $WIDTH -height $HEIGHT -background white
		pack   .c

		frame .fr
		pack  .fr -fill x -side top

		label .fr.filename -text {}
		pack  .fr.filename -side left

		label .fr.date -text {}
		pack  .fr.date -side right
	}

	proc displayLeft {s}  {
		.fr.filename configure -text $s
	}

	proc displayRight {s}  {
		.fr.date configure -text $s
	}

# --------------------------------------------------------------------
	set xOff     0
	set xZero   20
	set xMax   100
	set xScale   1

	set yOff     0
	set yZero    0
	set yMax   100
	set yScale   0.05

# ----------------------------
	proc scaleX {x}  {
		global xZero xScale xOff
		return [expr [expr $x - $xZero] * $xScale + $xOff]
	}

# --------
	proc scaleY {y}  {
		global yZero yScale HEIGHT yOff
		return [expr $yOff - [expr $y - $yZero] * $yScale ]
	}

# ----------------------------
	proc xAxis {xMin xMax} {
		global yOff WIDTH  xZero xOff yWidth

		.c create line $xOff $yOff [scaleX $xMax] $yOff

		set xDelta [expr int([expr $xMax - $xMin])]
		set xInc   [expr $xDelta / 10]
		set yTic   [expr $yOff - $yWidth]

		for { set xx [expr int($xMin)] } {$xx <= $xMax} {incr xx $xInc}  {
			set x [scaleX $xx]
			.c create line $x $yOff $x $yTic -fill gray
			.c create text $x $yOff -anchor n -text [format "%4d" $xx]
		}
	}

# --------
	proc yAxis {yMin yMax}  {
		global xOff HEIGHT yZero yOff xWidth

		.c create line $xOff [scaleY $yMax] $xOff $yOff

		set yInc [expr int([expr $yMax - $yMin]) / 10]
		set xTic [expr $xOff + 5]
		set xTic [expr $xOff + $xWidth]

		for {set yy [expr int($yMin) +$yInc]} {$yy <= $yMax} {incr yy $yInc}  {
			set y [scaleY $yy]
			.c create line $xOff $y $xTic $y -fill gray
			.c create text $xOff $y -anchor e -text [format "%4d" $yy]
		}
	}

# ----------------------------
	proc setScale {xMin xMax yMin yMax}  {
		global  WIDTH  xOff xZero xScale xWidth
		global  HEIGHT yOff yZero yScale yWidth

		set xOff   [expr $WIDTH * 0.1]
		set xZero  $xMin
		set xWidth [expr $WIDTH * 0.85] 
		set xScale [expr $xWidth / [expr $xMax - $xMin]]

		#	puts [format "xOff %f xZero %f xScale %f" $xOff $xZero $xScale]

		set yOff   [expr $HEIGHT * 0.9]
		set yZero  $yMin
		set yWidth [expr $HEIGHT * 0.85] 
		set yScale [expr $yWidth / [expr $yMax - $yMin] ]

		#	puts [format "yOff %f yZero %f yScale %f" $yOff $yZero $yScale]

	# clear screen
		.c delete all

	# draw axis
		xAxis $xMin $xMax
		yAxis $yMin $yMax

		.c create text [expr $WIDTH /2] $HEIGHT -anchor s \
				-text "Altitude vs Temperature (F)"

	# reset screen-text location
		global yInc yText
		set yText $yInc
	}

# ------------------------------------------------
	proc plotLine {x1 y1 x2 y2 color}  {
		set xVal0 [scaleX $x1]
		set yVal0 [scaleY $y1]
		set xVal1 [scaleX $x2]
		set yVal1 [scaleY $y2]

		.c create line $xVal0 $yVal0 $xVal1 $yVal1  -fill $color
	}

	proc plotLineDelta {x1 y1 dx2 dy2 color}  {
		set xVal0 [scaleX $x1]
		set yVal0 [scaleY $y1]
		set xVal1 [expr $xVal0 + $dx2]
		set yVal1 [expr $yVal0 + $dy2]

		.c create line $xVal0 $yVal0 $xVal1 $yVal1  -fill $color
	}

	proc plotCircle {x y radius color}  {
		set xVal  [scaleX $x]
		set yVal  [scaleY $y]
		set xVal0 [expr $xVal - $radius]
		set yVal0 [expr $yVal - $radius]
		set xVal1 [expr $xVal + $radius]
		set yVal1 [expr $yVal + $radius]

		.c create oval $xVal0 $yVal0 $xVal1 $yVal1 -outline $color
	}

# ------------------------------------------------
	set yInc  15
	set yText $yInc

	proc plotText {s color}  {
		global yInc yText HEIGHT WIDTH

		set xText [expr $WIDTH * 0.15]

		.c create text $xText $yText -anchor w -text $s -fill $color
		set yText [expr $yText + $yInc]
	}
